@@ -117,6 +117,8 @@ def alasso_v2(X_scaled, y, LAMBDAS = np.logspace(-10, 0, 11), gamma = 1, \
         test_errors.append(mse(X_test, Y_test, theta))
         theta_values.append(theta.value)
 
+    eps = 1e-9 # epsilon - non-zero coef cut threshold
+
     if display and len(lambd_values) > 1:
         
         # plot training curve
@@ -129,7 +131,6 @@ def alasso_v2(X_scaled, y, LAMBDAS = np.logspace(-10, 0, 11), gamma = 1, \
         plt.show()
 
         # plot non-zero coef curve
-        eps = 1e-9 # epsilon - cut threshold
         nz = []
 
         for coef in theta_values:
